        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 22 <br>2,6,7,9,12,16,18,22,27,29,30,31,32,33,37,38,39,41,43,44,47,49';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 14 <br>3,4,5,8,17,20,21,23,26,34,35,42,46,50';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <strong>control</strong><br>0,1,10,11,13,24,25,28,36,40,45';}
       if(rr==6 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 4 <br>14,15,19,48';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 22 <br>2,6,7,9,12,16,18,22,27,29,30,31,32,33,37,38,39,41,43,44,47,49';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 14 <br>3,4,5,8,17,20,21,23,26,34,35,42,46,50';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <strong>control</strong><br>0,1,10,11,13,24,25,28,36,40,45';}
       if(rr==29 && cc==4){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 4 <br>14,15,19,48';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 22 <br>2,6,7,9,12,16,18,22,27,29,30,31,32,33,37,38,39,41,43,44,47,49';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 14 <br>3,4,5,8,17,20,21,23,26,34,35,42,46,50';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <strong>control</strong><br>0,1,10,11,13,24,25,28,36,40,45';}
       if(rr==30 && cc==4){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 4 <br>14,15,19,48';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 22 <br>2,6,7,9,12,16,18,22,27,29,30,31,32,33,37,38,39,41,43,44,47,49';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 14 <br>3,4,5,8,17,20,21,23,26,34,35,42,46,50';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <strong>control</strong><br>0,1,10,11,13,24,25,28,36,40,45';}
       if(rr==31 && cc==4){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 4 <br>14,15,19,48';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 22 <br>2,6,7,9,12,16,18,22,27,29,30,31,32,33,37,38,39,41,43,44,47,49';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 14 <br>3,4,5,8,17,20,21,23,26,34,35,42,46,50';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <strong>control</strong><br>0,1,10,11,13,24,25,28,36,40,45';}
       if(rr==32 && cc==4){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 4 <br>14,15,19,48';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 22 <br>2,6,7,9,12,16,18,22,27,29,30,31,32,33,37,38,39,41,43,44,47,49';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 14 <br>3,4,5,8,17,20,21,23,26,34,35,42,46,50';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 11 <strong>control</strong><br>0,1,10,11,13,24,25,28,36,40,45';}
       if(rr==33 && cc==4){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260624 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>48</strong> miembros: 4 <br>14,15,19,48';}
}
